# Build switches:
#
# --without mp3       : don't build mp3 decoder plug-in
# --with mp3          : build with mp3 decoder plug-in
# --without mp3pkg    : include any mp3 plug-in files in main package
#
# --with kde32        : compile with KDE 3.2.x headers

# Activate this for hardcoded defaults.
#define _with_mp3 --with-mp3

# ----------------------------------------------------------------------------

# By default, build without mp3 decoder plug-in.
%{!?_with_mp3: %{!?_without_mp3: %define _without_mp3 --without-mp3 }}
# Force the user to specify with mp3 if libmad-devel is installed.
%{?_without_mp3:BuildConflicts: libmad-devel}

# If built without mp3 support, disable mp3 sub-package by default.
%if %{?_without_mp3:1}%{!?_without_mp3:0}
  %define _without_mp3pkg --without-mp3pkg
%endif

# ----------------------------------------------------------------------------
# KDE 3.2.x (Fedora Core 2) support.

%{?_with_kde32: %define target_kde32 1 }

# Auto-detect Fedora Core version when none of --with/without kde32 is given.
%if %(test -z "%{?_with_kde32}" -a -z "%{?_without_kde32}" && echo 1 || echo 0) 
  %define fedora_release %(if test -n "$(rpm -ql fedora-release | grep -m1 etc)";  then rpm -q --qf "%%{version}" fedora-release; else echo 0; fi )
  %if "%fedora_release" > "1"
    %define target_kde32 1
  %endif
%endif

# ----------------------------------------------------------------------------
# Avoid conflict with Arson package by using the same .desktop
# files for two MIME-types. See files section.
#
# KDE 3.2 includes the files already, k3b no longer.

%if %{!?_with_kde32:1}%{?_with_kde32:0}
  %define have_mimetypedefs 1
%else
  %define have_mimetypedefs %(if test -z $(rpm -ql kdelibs | grep -m1 x-iso.desktop); then echo 0; else echo 1; fi)
%endif

# ----------------------------------------------------------------------------
# If kde is built with selinux then we require it too.
# This is normally required only on Fedora Core 2

%define have_selinux %(%{_bindir}/ldd %{_bindir}/kdeinit 2>/dev/null|grep -c libselinux)
%if %{have_selinux}
BuildRequires: libselinux-devel
%endif

# ----------------------------------------------------------------------------

Name:           k3b
Version:        0.11.14
Release:        0.fdr.2.1
Epoch:          0
Summary:        CD/DVD burning application for KDE >= 3.1

Group:          Applications/Archiving
License:        GPL
URL:            http://www.k3b.org
Source:         http://dl.sf.net/k3b/k3b-0.11.14.tar.bz2
Patch1:         k3b-desktops.patch
Patch2:         k3b-0.11.3-kde32.patch
Patch3:         k3b-0.11.6-desktopfile.patch
Patch4:		k3b-0.11.14-version.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot-%(%{__id_u} -n)

BuildRequires:  XFree86-devel
BuildRequires:  kdelibs-devel >= 6:3.1, libart_lgpl-devel, arts-devel
BuildRequires:  zlib-devel, libpng-devel, libjpeg-devel
BuildRequires:  libvorbis-devel, audiofile-devel, flac-devel
BuildRequires:  id3lib-devel
BuildRequires:  desktop-file-utils
BuildRequires:  autoconf, gettext

%{?_with_mp3:BuildRequires: libmad-devel }

%if 0%{?target_kde32}
BuildRequires:  libmng-devel fam-devel glib2-devel alsa-lib-devel esound-devel
%endif

Requires:       kdebase, cdrecord, mkisofs

# If mp3 support is included in main package, provide "k3b-mp3".
%{?_with_mp3:%{?_without_mp3pkg:Provides: %{name}-mp3 = %{epoch}:%{version}-%{release} }}

# Updated k3b-i18n package is expected after KDE 3.2.
Obsoletes:      k3b-i18n < 0:0.11

Requires(post): /sbin/ldconfig
Requires(postun): /sbin/ldconfig

ExcludeArch: s390 s390x

%description
K3b was created to be a feature-rich and easy to handle CD/DVD
burning application.


%if %{!?_without_mp3pkg:1}%{?_without_mp3pkg:0}
%package mp3
Summary:        MP3 decoder plugin for %{name}
Group:          Applications/Multimedia
Requires:       %{name} = %{epoch}:%{version}

%description mp3
MP3 decoder plugin for %{name}.
%endif

%package devel
Summary:        Development files for k3b plugins
Group:          Development/Libraries
Requires:       %{name} = %{epoch}:%{version}

%description devel
Development files for K3b plugins.
Install k3b-devel if you wish to develop or compile any
applications for k3b.

%prep
%setup -q
%patch1 -p1 -b .desktops
%if 0%{?target_kde32}
%patch2 -p1 -b .forkde32
%endif
%patch3 -p1 -b .desktop-file-utils-0.3
%patch4 -p1 -b .version

# Make desktop icon file names compatible with GNOME.
sed -i 's,^Icon=k3b$,Icon=k3b.png,' src/k3b.desktop src/k3bsetup/k3bsetup2.desktop


%build
unset QTDIR
[ -z "$QTDIR" ] && . /etc/profile.d/qt.sh
%configure --disable-rpath
make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
desktop-file-install --vendor fedora --delete-original \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications \
  --add-category X-Fedora \
  $RPM_BUILD_ROOT%{_datadir}/applnk/Multimedia/%{name}.desktop

# KDE 3.1: Vendor must be "kde" to make it work as a KDE control centre
# module. Category "X-KDE-System" is for "System Administration" section.
desktop-file-install --vendor kde --delete-original \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications \
  --add-category X-Fedora \
  $RPM_BUILD_ROOT%{_datadir}/applnk/Settings/System/k3bsetup2.desktop
# KDE 3.2:
%if 0%{?target_kde32}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications/kde
mv $RPM_BUILD_ROOT%{_datadir}/applications/kde-k3bsetup2.desktop $RPM_BUILD_ROOT%{_datadir}/applications/kde/k3bsetup2.desktop
%endif

# Install custom mimetype desktop entries for KDE < 3.2.
%if !%{have_mimetypedefs}
install -p -m0644 x-cue.desktop $RPM_BUILD_ROOT%{_datadir}/mimelnk/application/x-cue.desktop
install -p -m0644 x-iso.desktop $RPM_BUILD_ROOT%{_datadir}/mimelnk/application/x-iso.desktop
%endif

# Empty directories.
rm -rf $RPM_BUILD_ROOT%{_datadir}/applnk

# GNOME desktop beautification (requires "Icon=name.png" fix in setup section).
mkdir $RPM_BUILD_ROOT%{_datadir}/pixmaps
ln -s ../icons/crystalsvg/48x48/apps/k3b.png $RPM_BUILD_ROOT%{_datadir}/pixmaps/k3b.png


%clean
rm -rf $RPM_BUILD_ROOT


%post
/sbin/ldconfig
if [ -x %{_bindir}/desktop-create-kmenu ] ; then
   %{_bindir}/desktop-create-kmenu >& /dev/null || :
fi


%postun
/sbin/ldconfig
if [ -x %{_bindir}/desktop-create-kmenu ] ; then
   %{_bindir}/desktop-create-kmenu >& /dev/null || :
fi


%files
%defattr(-,root,root,755)
%doc AUTHORS README COPYING TODO ChangeLog
%{_bindir}/%{name}
%{_bindir}/k3bsetup
%{_datadir}/applications/*.desktop
%if 0%{?target_kde32}
%{_datadir}/applications/kde/*.desktop
%endif

%if !%{have_mimetypedefs}
# Don't check modtime, because these files are shared with Arson package.
%verify(not mtime) %{_datadir}/mimelnk/application/x-cue.desktop
%verify(not mtime) %{_datadir}/mimelnk/application/x-iso.desktop
%endif
%{_datadir}/mimelnk/application/x-k3b.desktop


%{_libdir}/libk3b*.so.*
%{_libdir}/libk3b*.so
%{_libdir}/libk3b*.la

%{_libdir}/kde3/kcm_k3bsetup2.la
%{_libdir}/kde3/kcm_k3bsetup2.so
%{_libdir}/kde3/libk3b*.la
%{_libdir}/kde3/libk3b*.so

%{_datadir}/apps/k3b
%{_datadir}/apps/konqueror/servicemenus/*
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/sounds/*
%dir %{_datadir}/icons/crystalsvg/*/apps
%{_datadir}/icons/crystalsvg/*/apps/*.png
%{_datadir}/doc/HTML/en/%{name}

%if %{!?_without_mp3pkg:1}%{?_without_mp3pkg:0}
%exclude %{_libdir}/kde3/libk3bmaddecoder.*
%exclude %{_datadir}/apps/k3b/plugins/k3bmaddecoder.plugin

# Optional separate mp3 plugin sub-package.
%files mp3
%defattr(-,root,root,755)
%{_libdir}/kde3/libk3bmaddecoder.*
%{_datadir}/apps/k3b/plugins/k3bmaddecoder.plugin
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/k3b*.h
%{_includedir}/kcutlabel.h

%changelog
* Fri Oct 15 2004 Mihai Maties <mihai[AT]xcyb.org> - 0:0.11.14-0.fdr.2
- fixed version string parsing, which fixes bug 134642 (.version patch)

* Mon Aug 10 2004 Mihai Maties <mihai[AT]xcyb.org> - 0:0.11.14-0.fdr.1
- removed the qt31 patch (fixed upstream) [ errr... I'm begining to see
a pattern here ]

* Mon Aug  9 2004 Mihai Maties <mihai[AT]xcyb.org> - 0:0.11.13-0.fdr.1
- added yet another patch for qt-3.1 compatibility

* Tue Jun 29 2004 Mihai Maties <mihai[AT]xcyb.org> - 0:0.11.12-0.fdr.2
- redirected stderr to /dev/null when checking for libselinux BuildRequires
( https://bugzilla.fedora.us/show_bug.cgi?id=1668#c26 )

* Mon Jun 28 2004 Mihai Maties <mihai[AT]xcyb.org> - 0:0.11.12-0.fdr.1
- update to 0.11.12
- removed the qt31 patch (fixed upstream)

* Fri Jun 18 2004 Mihai Maties <mihai[AT]xcyb.org> - 0:0.11.11-0.fdr.1
- update to 0.11.11
- updated the qt31 patch

* Fri May 28 2004 Mihai Maties <mihai[AT]xcyb.org> - 0:0.11.10-0.fdr.3
- unset QTDIR before build

* Fri May 28 2004 Mihai Maties <mihai[AT]xcyb.org> - 0:0.11.10-0.fdr.2
- fixed permissions for files in the devel package
- exclude the s390 and s390x arhitectures
- improved the "compile k3b on qt-3.1" and applied it on qt-3.2, too
- removed redundant BuildRequires qt-devel (pulled in by kdelibs-devel)
- removed INSTALL from docs
- disable -rpath on linking

* Thu May 27 2004 Mihai Maties <mihai[AT]xcyb.org> - 0:0.11.10-0.xcyb.1
- removed libsamplerate dependency / using the sources provided by K3b
- created a separate k3b-devel package
- added libselinux-devel to BuildRequires only if needed (for FC2)
- applied a patch to compile k3b on qt-3.1

* Mon Mar 29 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.9-0.fdr.1
- Update to 0.11.9.

* Mon Mar 29 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.8-0.fdr.1
- Update to 0.11.8.

* Sun Mar 28 2004 Michael Schwendt <mschwendt[AT]users.sf.net>
- Rewrite the conditional code sections, although they work fine in
  normal build environments and the fedora.us build system. But 'mach'
  makes some weird assumptions about build requirements in spec files
  and causes unexpected results.

* Mon Mar  1 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.6-0.fdr.1
- Update to 0.11.6.
- Fix Fedora Core 2 detection.
- Fix k3b.desktop, so it doesn't break desktop-file-utils 0.4.

* Sun Feb 22 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.5-0.fdr.1
- Update to 0.11.5.
- Make id3lib-devel unconditional buildreq (FLAC plug-in wants this).

* Tue Feb 17 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.4-0.fdr.1
- Update to 0.11.4 (minor bug-fix release).

* Fri Feb 13 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.3-0.fdr.1
- Update to 0.11.3.
- Patch2 (kde31) from previous package obsolete.
- Docbook is there again.
- Add conditional build dependencies and preliminary KDE 3.2
  integration work for Fedora Core 2.

* Mon Feb  9 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.2-0.fdr.1
- Update to 0.11.2.
- Patch one line in the source which is specific to KDE 3.2 API and
  when the available KDE header seems insufficient.
- Docbook is gone.

* Mon Feb  9 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.1-0.fdr.5
- Add libsamplerate buildreq.
- Add check for and conditional inclusion of the x-cue/x-iso MIME type files.
- Drop patching default desktop categories, they don't contain a bug anymore.

* Mon Feb  2 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.1-0.fdr.4
- Add detection of mp3 build dependencies, and default to build with
  mp3 when found.
- Enable build conflicts on optional mp3 software only if built --without mp3.

* Sat Jan 31 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.1-0.fdr.3
- Extend scriptlets to complete KDE menu hierarchy.
- Replace perl one-liners with sed.

* Sun Jan 25 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.1-0.fdr.2
- Apply some fedora.us QA suggestions (not own some directories, symlink
  desktop icon).

* Sat Jan 24 2004 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.11.1-0.fdr.1
- Update to 0.11.1, add flac-devel buildreq, and --with mp3 switch.
- No longer needed: kcmshell desktop entry patch.
- Obsolete k3b-i18n < 0.11, upstream will release a new one.

* Wed Dec 10 2003 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.10.3-0.lvn.2
- Add proper %%defattr for mp3 sub-package.

* Thu Dec  4 2003 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.10.3-0.lvn.1
- Add libmad-devel and id3lib-devel buildreq.
- Add --without-mp3 and --without-mp3pkg build switches.
- Update to 0.10.3.

* Fri Nov 14 2003 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.10.2-0.fdr.2
- Don't own /usr/share/sounds.

* Thu Nov 06 2003 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.10.2-0.fdr.1
- Update to 0.10.2.

* Tue Oct 28 2003 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.10.1-0.fdr.2
- Apply Fedora QA suggestions (bug #885).

* Sun Oct 26 2003 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.10.1-0.fdr.1
- Update to 0.10.1.

* Sun Oct 26 2003 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.10-0.fdr.1
- Update to 0.10.
- Add autoconf buildreq.
- Remove mp3 input Makefile patch (obsolete).
- Remove k3bsetuprc ghost file (obsolete).
- Add rpm optflags patch.
- Fix desktop file for KDE control centre module.
- Make desktop entry icons work in GNOME.
- Remove --with-xinerama
- Spec file cleanup (brings it closer to Fedora spec template).

* Sun Oct 26 2003 Ville Skytta <ville.skytta at iki.fi> - 0:0.9-0.fdr.7
- Provide k3b-devel.

* Sun Oct 26 2003 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.9-0.fdr.6
- Fix German comment in k3b-desktop.patch.

* Sat Sep 06 2003 Michael Schwendt <mschwendt[AT]users.sf.net> - 0:0.9-0.fdr.5
- Remove conflict with Arson package by using the same .desktop
  files for two MIME-types.

* Sat Aug 23 2003 Adrian Reber <adrian@lisas.de> - 0:0.9-0.fdr.4
- perl one-liner to remove -pedantic. k3b does now compile on
  RH 9.0.93 (bug #572)
- included k3bsetup.patch from debian (bug #500)

* Sun Aug 03 2003 Adrian Reber <adrian@lisas.de> - 0:0.9-0.fdr.3
- switched back to kdesu as usermode-gtk did not work in all places
- added a lot of directories to the file list
- datadir/apps/k3b/k3bsetup marked as ghost

* Tue Jul 29 2003 Adrian Reber <adrian@lisas.de> - 0:0.9-0.fdr.2
- applied patch from Michael Schwendt to use usermode-gtk 
  instead of kdesu

* Tue Jul 22 2003 Adrian Reber <adrian@lisas.de> - 0:0.9-0.fdr.1
- updated to 0.9
- included kdebase as requires (for kdesu)
- included headers and libs
- included post and postun scripts

* Sun May 25 2003 Adrian Reber <adrian@lisas.de> - 0:0.8.1-0.fdr.7
- added conflicts with arson
- synced the spec with the one from the fedora repository

* Mon May 12 2003 Adrian Reber <adrian@lisas.de> - 0:0.8.1-0.fdr.6
- removed desktop categories from k3b.desktop which do not belong
  there
- inserted perl as BuildRequires to optimize the desktop categories

* Mon May 05 2003 Adrian Reber <adrian@lisas.de> - 0:0.8.1-0.fdr.5
- release has been incremented

* Mon May 05 2003 Adrian Reber <adrian@lisas.de> - 0:0.8.1-0.fdr.4
- changed the desktop categories according to fedora bug #261

* Fri Apr 25 2003 Warren Togami <warren@togami.com> 0:0.8.1-0.fdr.4
- Remove macros from URL

* Wed Apr 23 2003 Adrian Reber <adrian@lisas.de> - 0:0.8.1-0.fdr.3
- added %{?_smp_mflags}
- added --with-xinerama
- moved QTDIR and configure from prep to build
- removed X-Red-Hat-Extra from .desktop
- macroless URL for Source

* Tue Apr 15 2003 Adrian Reber <adrian@lisas.de> - 0.8.1-0.fdr.2
- added Epoch: 0
- added %doc

* Sat Apr 12 2003 Adrian Reber <adrian@lisas.de> - 0.8.1-0.fdr.1
- changed existing spec file to comply with the fedora guidlines
